@@ -1,4 +1,3 @@
-
 /*
   This file is part of g15daemon.
   
@@ -70,7 +69,7 @@
 
 /* Some useful costants */
 #define WIDTH 256
-#define PLUGIN_VERSION "2.5.5"
+#define PLUGIN_VERSION "2.5.7"
 #define PLUGIN_NAME    "G15daemon Visualization Plugin"
 #define INFERIOR_SPACE 7 /* space between bars and position bar */
 #define SUPERIOR_SPACE 7 /* space between bars and top of lcd   */
@@ -203,7 +202,7 @@ static int volume;
 
 /* gdk stuff */
 static GtkWidget *configure_win = NULL;
-static GtkWidget *vbox;
+static GtkWidget *vbox, *hbox;
 static GtkWidget *bbox, *ok, *cancel, *apply, *defaults;
 static GtkWidget *t_options_bars_radio, *t_options_scope_radio;
 static GtkWidget *t_options_effect_no, *t_options_effect_line, *t_options_effect_peak, *t_options_effect_analog;
@@ -286,29 +285,51 @@ VisPlugin *get_vplugin_info(void) {
 void g15spectrum_read_config(void)
 {
   ConfigDb *cfg;
-  
+#if  __AUDACIOUS_PLUGIN_API__ < 7
   cfg = bmp_cfg_db_open();
+#else
+  cfg = aud_cfg_db_open();
+#endif
   pthread_mutex_lock (&g15buf_mutex);
   if (cfg)
     {
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "visualisation_type", (int*)&vis_type);
-      bmp_cfg_db_get_float(cfg, "G15Daemon Spectrum", "linearity", (float*)&linearity);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "amplification", (int*)&amplification);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "bars_limit", (int*)&limit);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "num_bars", (int*)&num_bars);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "enable_peak", (int*)&enable_peak);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "detached_peak", (int*)&detached_peak);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "line_mode", (int*)&line_mode);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "analog_mode", (int*)&analog_mode);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "analog_step", (int*)&analog_step);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "enable_keybindings", (int*)&enable_keybindings);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "show_title", (int*)&show_title);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "show_pbar", (int*)&show_pbar);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "show_time", (int*)&show_time);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "rownum", (int*)&rownum);
-      bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "title_overlay", (int*)&title_overlay);
-      
-      bmp_cfg_db_close(cfg);
+      #if  __AUDACIOUS_PLUGIN_API__ < 7
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "visualisation_type", (int*)&vis_type);
+	bmp_cfg_db_get_float(cfg, "G15Daemon Spectrum", "linearity", (float*)&linearity);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "amplification", (int*)&amplification);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "bars_limit", (int*)&limit);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "num_bars", (int*)&num_bars);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "enable_peak", (int*)&enable_peak);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "detached_peak", (int*)&detached_peak);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "line_mode", (int*)&line_mode);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "analog_mode", (int*)&analog_mode);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "analog_step", (int*)&analog_step);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "enable_keybindings", (int*)&enable_keybindings);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "show_title", (int*)&show_title);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "show_pbar", (int*)&show_pbar);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "show_time", (int*)&show_time);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "rownum", (int*)&rownum);
+	bmp_cfg_db_get_int(cfg, "G15Daemon Spectrum", "title_overlay", (int*)&title_overlay);
+      	bmp_cfg_db_close(cfg);
+      #else
+	/* New version of audacious */
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "visualisation_type", (int*)&vis_type);
+	aud_cfg_db_get_float(cfg, "G15Daemon Spectrum", "linearity", (float*)&linearity);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "amplification", (int*)&amplification);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "bars_limit", (int*)&limit);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "num_bars", (int*)&num_bars);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "enable_peak", (int*)&enable_peak);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "detached_peak", (int*)&detached_peak);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "line_mode", (int*)&line_mode);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "analog_mode", (int*)&analog_mode);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "analog_step", (int*)&analog_step);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "enable_keybindings", (int*)&enable_keybindings);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "show_title", (int*)&show_title);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "show_pbar", (int*)&show_pbar);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "show_time", (int*)&show_time);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "rownum", (int*)&rownum);
+	aud_cfg_db_get_int(cfg, "G15Daemon Spectrum", "title_overlay", (int*)&title_overlay);
+      #endif
       
     }
   /* check conf integrity */
@@ -350,11 +371,15 @@ void g15spectrum_read_config(void)
 void g15spectrum_write_config(void)
 {
   ConfigDb *cfg;
-  
+#if  __AUDACIOUS_PLUGIN_API__ < 7
   cfg = bmp_cfg_db_open();
-  
+#else
+  cfg = aud_cfg_db_open();
+#endif 
+   
   if (cfg)
     {
+#if  __AUDACIOUS_PLUGIN_API__ < 7
       bmp_cfg_db_set_int(cfg, "G15Daemon Spectrum", "visualisation_type", vis_type);
       bmp_cfg_db_set_float(cfg, "G15Daemon Spectrum", "linearity", linearity);
       bmp_cfg_db_set_int(cfg, "G15Daemon Spectrum", "amplification", amplification);
@@ -372,6 +397,26 @@ void g15spectrum_write_config(void)
       bmp_cfg_db_set_int(cfg, "G15Daemon Spectrum", "rownum", rownum);
       bmp_cfg_db_set_int(cfg, "G15Daemon Spectrum", "title_overlay", title_overlay);
       bmp_cfg_db_close(cfg);
+#else
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "visualisation_type", vis_type);
+      aud_cfg_db_set_float(cfg, "G15Daemon Spectrum", "linearity", linearity);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "amplification", amplification);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "bars_limit", limit);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "num_bars", num_bars);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "enable_peak", enable_peak);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "detached_peak", detached_peak);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "analog_mode", analog_mode);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "line_mode", line_mode);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "analog_step", analog_step);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "enable_keybindings", enable_keybindings);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "show_title", show_title);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "show_pbar", show_pbar);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "show_time", show_time);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "rownum", rownum);
+      aud_cfg_db_set_int(cfg, "G15Daemon Spectrum", "title_overlay", title_overlay);
+      aud_cfg_db_close(cfg);
+#endif
+
     }
   
 }
@@ -520,13 +565,16 @@ void g15analyser_conf(void){
   gtk_window_set_policy(GTK_WINDOW(configure_win), FALSE, FALSE, FALSE);
   gtk_window_set_position(GTK_WINDOW(configure_win), GTK_WIN_POS_MOUSE);
   gtk_signal_connect(GTK_OBJECT(configure_win), "destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &configure_win);
-  
+
   vbox = gtk_vbox_new(FALSE, 5);
-  
+  gtk_widget_show(vbox);
+  gtk_container_add(GTK_CONTAINER(configure_win), vbox);
+ 
   /* general config */
   
   g_options_frame = gtk_frame_new("General:");
   gtk_container_set_border_width(GTK_CONTAINER(g_options_frame), 5);
+  gtk_widget_set_size_request (g_options_frame, 258, -1);
   t_options_vistype = gtk_vbox_new(FALSE, 5);
   label = gtk_label_new("Visualization Type:");
   gtk_misc_set_alignment(GTK_MISC (label), 0, 0);
@@ -594,10 +642,16 @@ void g15analyser_conf(void){
   gtk_widget_show(g_options_frame);
   
   
+  hbox = gtk_hbox_new(FALSE, 5);
+  gtk_widget_show(hbox);
+  //gtk_container_add(GTK_BOX (vbox), hbox);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
+
   /* bars config */
   
   g_options_frame_bars = gtk_frame_new("Spectrum bars options:");
   gtk_container_set_border_width(GTK_CONTAINER(g_options_frame), 5);
+  //gtk_widget_set_size_request (g_options_frame_bars, 258, 258);
   t_options_bars = gtk_vbox_new(FALSE, 5);
   /* number of the bars */
   label_bars=gtk_label_new("Num Bars:");
@@ -641,13 +695,14 @@ void g15analyser_conf(void){
   /* draw frame */
   gtk_container_add(GTK_CONTAINER(g_options_frame_bars), t_options_bars); 
   gtk_widget_show(t_options_bars);
-  gtk_box_pack_start(GTK_BOX(vbox), g_options_frame_bars, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(hbox), g_options_frame_bars, TRUE, TRUE, 0);
   gtk_widget_show(g_options_frame_bars);
   
   
   /* bars effects */
   g_options_frame_bars_effects = gtk_frame_new("Spectrum bars effects:");
   gtk_container_set_border_width(GTK_CONTAINER(g_options_frame_bars_effects), 5);
+  //gtk_widget_set_size_request (g_options_frame_bars_effects, 258, 268);
   t_options_bars_effects = gtk_vbox_new(FALSE, 5);
   /* radio effect type */
   t_options_effect_no     = gtk_radio_button_new_with_label(NULL, "None");
@@ -694,7 +749,7 @@ void g15analyser_conf(void){
   /* draw frame */
   gtk_container_add(GTK_CONTAINER(g_options_frame_bars_effects), t_options_bars_effects); 
   gtk_widget_show(t_options_bars_effects);
-  gtk_box_pack_start(GTK_BOX(vbox), g_options_frame_bars_effects, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(hbox), g_options_frame_bars_effects, TRUE, TRUE, 0);
   gtk_widget_show(g_options_frame_bars_effects);
   
   
@@ -704,34 +759,33 @@ void g15analyser_conf(void){
   gtk_button_box_set_spacing(GTK_BUTTON_BOX(bbox), 5);
   gtk_box_pack_start(GTK_BOX(vbox), bbox, FALSE, FALSE, 0);
   
-  ok = gtk_button_new_with_label(" Ok ");
+  ok = gtk_button_new_from_stock ("gtk-save");
   gtk_signal_connect(GTK_OBJECT(ok), "clicked", GTK_SIGNAL_FUNC(g15analyser_conf_ok), NULL);
   GTK_WIDGET_SET_FLAGS(ok, GTK_CAN_DEFAULT);
   gtk_box_pack_start(GTK_BOX(bbox), ok, TRUE, TRUE, 0);
   gtk_widget_show(ok);
   
-  apply = gtk_button_new_with_label(" Apply ");
+  apply = gtk_button_new_from_stock ("gtk-apply");
   gtk_signal_connect(GTK_OBJECT(apply), "clicked", GTK_SIGNAL_FUNC(g15analyser_conf_apply), NULL);
   GTK_WIDGET_SET_FLAGS(apply, GTK_CAN_DEFAULT);
   gtk_box_pack_start(GTK_BOX(bbox), apply, TRUE, TRUE, 0);
   gtk_widget_show(apply);
   
-  defaults = gtk_button_new_with_label(" Reset ");
+  defaults = gtk_button_new_from_stock ("gtk-revert-to-saved");
   gtk_signal_connect(GTK_OBJECT(defaults), "clicked", GTK_SIGNAL_FUNC(g15analyser_conf_reset_defaults_gui), NULL);
   GTK_WIDGET_SET_FLAGS(defaults, GTK_CAN_DEFAULT);
   gtk_box_pack_start(GTK_BOX(bbox), defaults, TRUE, TRUE, 0);
   gtk_widget_show(defaults);
   
-  cancel = gtk_button_new_with_label("Cancel");
+  cancel = gtk_button_new_from_stock ("gtk-cancel");
   gtk_signal_connect_object(GTK_OBJECT(cancel), "clicked", GTK_SIGNAL_FUNC(g15analyser_conf_cancel), GTK_OBJECT(configure_win));
   GTK_WIDGET_SET_FLAGS(cancel, GTK_CAN_DEFAULT);
   gtk_box_pack_start(GTK_BOX(bbox), cancel, TRUE, TRUE, 0);
   
-  gtk_container_add(GTK_CONTAINER(configure_win), vbox);
   /* Show all */
   gtk_widget_show(cancel);
   gtk_widget_show(bbox);
-  gtk_widget_show(vbox);
+
   gtk_widget_show(configure_win);
   return;
 }
@@ -776,13 +830,14 @@ void g15analyser_about(void){
 
 static int poll_g15keys() {
   int keystate = 0;
+  int ret;
   struct pollfd fds;
   
   fds.fd = g15screen_fd;
   fds.events = POLLIN;
   
-  if ((poll(&fds, 1, 5)) > 0);
-  read (g15screen_fd, &keystate, sizeof (keystate));
+  if ((poll(&fds, 1, 5)) > 0)
+    ret = read(g15screen_fd, &keystate, sizeof (keystate));
   
   if (keystate) {
     pthread_mutex_lock (&g15buf_mutex);
